import { IonButton, IonIcon } from '@ionic/react';
import { cloudDownload } from 'ionicons/icons';
import React, { Fragment, useLayoutEffect, useRef, useState } from 'react';
import { useDB } from 'react-pouchdb';

const GpxExport: React.FC<{ gpxId: string }> = (props: { gpxId: string }) => {
  const db = useDB();

  const hiddenLinkElement = useRef<HTMLAnchorElement>(null);

  const [fileDownloadUrl, setFileDownloadUrl] = useState('');

  useLayoutEffect(() => {
    if (fileDownloadUrl !== '') {
      hiddenLinkElement.current?.click();
      URL.revokeObjectURL(fileDownloadUrl);
      setFileDownloadUrl('');
    }
  }, [fileDownloadUrl]);

  const download = (event: any) => {
    event.preventDefault();
    const blob = new Blob(['<gpx/>'], { type: 'application/gpx+xml' });
    const fileDownloadUrl = URL.createObjectURL(blob);
    setFileDownloadUrl(fileDownloadUrl);
  };

  return (
    <Fragment>
      <IonButton id='gpx-export-button' onClick={download}>
        <IonIcon icon={cloudDownload} title='Export' slot='icon-only' />
      </IonButton>
      <a
        className='hidden'
        download={props.gpxId + '.gpx'}
        href={fileDownloadUrl}
        ref={hiddenLinkElement}
      >
        download it
      </a>
    </Fragment>
  );
};

export default GpxExport;
